package cn.com.qmth.examcloud.starters.face.verify.service.faceplus;

import cn.com.qmth.examcloud.starters.face.verify.common.HttpClientBuilder;
import cn.com.qmth.examcloud.starters.face.verify.common.JsonHelper;
import okhttp3.*;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.IOException;

public class FacePlusApiHelper {

    private final static Logger log = LoggerFactory.getLogger(FacePlusApiHelper.class);

    public static FacePlusResponse faceDetect(String apiKey, String apiSecret, String apiUrl, String imageUrl) {
        if (StringUtils.isBlank(apiKey)) {
            throw new IllegalArgumentException("Face++ apiKey must be not empty.");
        }

        if (StringUtils.isBlank(apiSecret)) {
            throw new IllegalArgumentException("Face++ apiSecret must be not empty.");
        }

        if (StringUtils.isBlank(apiUrl)) {
            throw new IllegalArgumentException("Face++ apiUrl must be not empty.");
        }

        if (StringUtils.isBlank(imageUrl)) {
            throw new IllegalArgumentException("face imageUrl must be not empty.");
        }

        MultipartBody.Builder formBody = new MultipartBody.Builder().setType(MultipartBody.FORM)
                .addFormDataPart("api_key", apiKey)
                .addFormDataPart("api_secret", apiSecret)
                .addFormDataPart("image_url", imageUrl);
        Request.Builder request = new Request.Builder().url(apiUrl).post(formBody.build());

        return callApi(apiUrl, request);
    }

    public static FacePlusResponse faceCompare(String apiKey, String apiSecret, String apiUrl, String imageUrl, String imageUrl2) {
        if (StringUtils.isBlank(apiKey)) {
            throw new IllegalArgumentException("Face++ apiKey must be not empty.");
        }

        if (StringUtils.isBlank(apiSecret)) {
            throw new IllegalArgumentException("Face++ apiSecret must be not empty.");
        }

        if (StringUtils.isBlank(apiUrl)) {
            throw new IllegalArgumentException("Face++ apiUrl must be not empty.");
        }

        if (StringUtils.isBlank(imageUrl)) {
            throw new IllegalArgumentException("face imageUrl must be not empty.");
        }

        if (StringUtils.isBlank(imageUrl2)) {
            throw new IllegalArgumentException("face imageUrl2 must be not empty.");
        }

        RequestBody formBody = new FormBody.Builder()
                .add("api_key", apiKey)
                .add("api_secret", apiSecret)
                .add("image_url1", imageUrl)
                .add("image_url2", imageUrl2)
                .build();
        Request.Builder request = new Request.Builder().url(apiUrl).post(formBody);

        return callApi(apiUrl, request);
    }

    private static FacePlusResponse callApi(String apiUrl, Request.Builder request) {
        FacePlusResponse result = null;
        try (Response response = HttpClientBuilder.getClient().newCall(request.build()).execute();
             ResponseBody body = response.body();) {
            String bodyStr = body.string();

            System.out.println(bodyStr);

            if (response.code() == 403 || response.isSuccessful()) {
                result = new JsonHelper().parseJson(bodyStr, FacePlusResponse.class);
            } else {
                log.warn("[Face++] url:{} response:{} body:{}", apiUrl, response.code(), bodyStr);
            }
        } catch (IOException e) {
            log.error(e.getMessage(), e);
        }

        return result;
    }

}
