package cn.com.qmth.examcloud.starters.face.verify.service.faceplus;

import cn.com.qmth.examcloud.starters.face.verify.common.IResult;
import cn.com.qmth.examcloud.starters.face.verify.common.JsonHelper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.List;

public class FacePlusResponse implements IResult {

    private static final long serialVersionUID = 1L;

    private static Logger log = LoggerFactory.getLogger(FacePlusResponse.class);

    private String request_id;

    private Float confidence;

    private FacePlusThresholds thresholds;

    private Integer time_used;

    private String error_message;

    private String image_id;

    private List<FacePlusFace> faces;

    @Override
    public boolean isDetectPass() {
        //是否人脸活体检测通过 (只有一张人脸算成功，否则算失败)
        if (faces != null) {
            log.info("faces size:" + faces.size());

            if (faces.size() == 1) {
                return true;
            }
        }

        return false;
    }

    @Override
    public boolean isComparePass() {
        //是否人脸识别对比通过
        if (confidence != null && thresholds != null && confidence >= thresholds.getLe_4()) {
            return true;
        }
        return false;
    }

    @Override
    public Double getConfidenceValue() {
        //置信度
        if (confidence != null) {
            return confidence.doubleValue();
        }
        return null;
    }

    @Override
    public String getThresholdValue() {
        //置信度阈值(JSON)
        if (thresholds != null) {
            return new JsonHelper().toJson(thresholds);
        }
        return null;
    }

    @Override
    public int getFaceSize() {
        //人脸数
        if (faces == null) {
            return 0;
        }
        return faces.size();
    }

    @Override
    public boolean requestOutOfLimit() {
        //请求并发是否超限(默认20个/秒)
        if ("CONCURRENCY_LIMIT_EXCEEDED".equals(getError_message())) {
            return true;//Face++错误码为CONCURRENCY_LIMIT_EXCEEDED
        }

        return false;
    }

    public String getRequest_id() {
        return request_id;
    }

    public void setRequest_id(String request_id) {
        this.request_id = request_id;
    }

    public Float getConfidence() {
        return confidence;
    }

    public void setConfidence(Float confidence) {
        this.confidence = confidence;
    }

    public FacePlusThresholds getThresholds() {
        return thresholds;
    }

    public void setThresholds(FacePlusThresholds thresholds) {
        this.thresholds = thresholds;
    }

    public Integer getTime_used() {
        return time_used;
    }

    public void setTime_used(Integer time_used) {
        this.time_used = time_used;
    }

    public String getError_message() {
        return error_message;
    }

    public void setError_message(String error_message) {
        this.error_message = error_message;
    }

    public String getImage_id() {
        return image_id;
    }

    public void setImage_id(String image_id) {
        this.image_id = image_id;
    }

    public List<FacePlusFace> getFaces() {
        return faces;
    }

    public void setFaces(List<FacePlusFace> faces) {
        this.faces = faces;
    }

}