package cn.com.qmth.examcloud.starters.face.verify.service.impl;

import cn.com.qmth.examcloud.starters.face.verify.FaceVerifyProperties;
import cn.com.qmth.examcloud.starters.face.verify.common.IResult;
import cn.com.qmth.examcloud.starters.face.verify.service.FaceVerifyService;
import cn.com.qmth.examcloud.starters.face.verify.service.baidu.BaiduApiHelper;
import cn.com.qmth.examcloud.starters.face.verify.service.baidu.BaiduSession;
import cn.com.qmth.examcloud.starters.face.verify.service.faceplus.FacePlusApiHelper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class FaceVerifyServiceImpl implements FaceVerifyService {

    private final static Logger log = LoggerFactory.getLogger(FaceVerifyServiceImpl.class);

    private FaceVerifyProperties properties;

    @Override
    public IResult faceDetectByBaidu(String imageUrl) {
        String accessToken = null;
        if (properties.getBaiduAccessTokenEnabled()) {
            BaiduSession session = BaiduApiHelper.getAccessToken(properties.getBaiduKey(), properties.getBaiduSecret(), properties.getBaiduTokenUrl());
            accessToken = session.getAccess_token();
        }

        return BaiduApiHelper.faceDetect(accessToken, properties.getBaiduFaceDetectUrl(), imageUrl);
    }

    @Override
    public IResult faceCompareByBaidu(String imageUrl, String imageUrl2) {
        String accessToken = null;
        if (properties.getBaiduAccessTokenEnabled()) {
            BaiduSession session = BaiduApiHelper.getAccessToken(properties.getBaiduKey(), properties.getBaiduSecret(), properties.getBaiduTokenUrl());
            accessToken = session.getAccess_token();
        }

        return BaiduApiHelper.faceCompare(accessToken, properties.getBaiduFaceCompareUrl(), imageUrl, imageUrl2);
    }

    @Override
    public IResult faceDetectByFacePlus(String imageUrl) {
        return FacePlusApiHelper.faceDetect(properties.getFacePlusKey(), properties.getFacePlusSecret(), properties.getFacePlusFaceDetectUrl(), imageUrl);
    }

    @Override
    public IResult faceCompareByFacePlus(String imageUrl, String imageUrl2) {
        return FacePlusApiHelper.faceCompare(properties.getFacePlusKey(), properties.getFacePlusSecret(), properties.getFacePlusFaceCompareUrl(), imageUrl, imageUrl2);
    }

    public void setProperties(FaceVerifyProperties properties) {
        this.properties = properties;
    }

}
